from django import forms

from .models import SiteMetadataPreferences


class SiteMetadataPreferencesForm(forms.ModelForm):

    class Meta:
        model = SiteMetadataPreferences
        exclude = ('site', )



from django import template
from django.conf import settings
from django.template.loader import render_to_string
from django.utils.html import format_html
from wagtail.wagtailcore.models import Site
from wagtailmetadata.models import SiteMetadataPreferences

register = template.Library()


@register.simple_tag(takes_context=True)
def meta_tags(context):
    instance = context['self']
    request = context['request']
    page = context['self']
    site = Site.find_for_request(request)
    try:
        global_settings = SiteMetadataPreferences.objects.get(site=site)
    except SiteMetadataPreferences.DoesNotExist:
        return format_html('<!-- Please define your global metadata settings -->')

    instance.meta_image = instance.search_image or global_settings.site_image
    instance.meta_description = instance.search_description or global_settings.site_description

    instance.meta_image = instance.meta_image.get_rendition(filter='original')
    instance.meta_image.full_url = request.build_absolute_uri(instance.meta_image.url)

    page.absolute_url = request.build_absolute_uri(page.url)
    return render_to_string('wagtailmetadata/parts/tags.html', {
        'instance': instance,
        'page': page,
        'site_name': settings.WAGTAIL_SITE_NAME,
        'global_settings': global_settings,
    })


@register.simple_tag()
def tot(first, second):
    """
    This or that, here shortened to 'tot'
    will display a variable if it exists,
    and if it doesn't, will display the second
    variable passed through, and finally, none.
    """
    if first:
        return first
    elif second:
        return second
    else:
        return None



# -*- coding: utf-8 -*-
# Generated by Django 1.9.1 on 2016-02-15 03:38
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('wagtailimages', '0010_change_on_delete_behaviour'),
        ('wagtailcore', '0023_alter_page_revision_on_delete_behaviour'),
    ]

    operations = [
        migrations.CreateModel(
            name='SiteMetadataPreferences',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('site_description', models.TextField()),
                ('card_type', models.CharField(choices=[('summary', 'Summary card'), ('summary_large_image', 'Summary card with large image')], max_length=128)),
                ('site', models.OneToOneField(editable=False, on_delete=django.db.models.deletion.CASCADE, to='wagtailcore.Site')),
                ('site_image', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='wagtailimages.Image')),
            ],
        ),
    ]



from django.shortcuts import redirect, render
from django.utils.lru_cache import lru_cache
from django.utils.translation import ugettext_lazy
from wagtail.wagtailadmin import messages
from wagtail.wagtailadmin.edit_handlers import ObjectList, TabbedInterface
from wagtail.wagtailcore.models import Site

from .models import SiteMetadataPreferences


@lru_cache()
def get_edit_handler(cls):
    if hasattr(cls, 'edit_handler'):
        return cls.edit_handler.bind_to_model(cls)

    # construct a TabbedInterface made up of content_panels, promote_panels
    # and settings_panels, skipping any which are empty
    tabs = []

    tabs.append(ObjectList(cls.general_panels, heading=ugettext_lazy('General')))
    tabs.append(ObjectList(cls.twitter_panels, heading=ugettext_lazy('Twitter'), classname="settings"))

    EditHandler = TabbedInterface(tabs)
    return EditHandler.bind_to_model(cls)


def index(request):
    site = Site.find_for_request(request)
    instance = SiteMetadataPreferences.objects.filter(site=site).first()
    if instance is None:
        instance = SiteMetadataPreferences(site=site)
    EditHandler = get_edit_handler(SiteMetadataPreferences)
    SiteMetadataPreferencesForm = EditHandler.get_form_class(SiteMetadataPreferences)

    if request.method == "POST":
        form = SiteMetadataPreferencesForm(request.POST, instance=instance)
        if form.is_valid():
            form.save()
            messages.success(request, 'The form has been successfully saved.')
            return redirect('wagtailmetadata')
        else:
            messages.error(request, 'The form could not be saved due to validation errors')
    else:
        form = SiteMetadataPreferencesForm(instance=instance)

    edit_handler = EditHandler(instance=instance, form=form)

    return render(request, 'wagtailmetadata/index.html', {
        'form': form,
        'edit_handler': edit_handler,
    })
